@@ -18,7 +18,7 @@ v_job_id                    bigint;
 v_jobmon                    boolean;
 v_jobmon_schema             text;
 v_max                       bigint;
-v_new_search_path           text := '@extschema@,pg_temp';
+v_new_search_path           text;
 v_old_search_path           text;
 v_parent_schema             text;
 v_parent_tablename          text;
@@ -109,10 +109,15 @@ IF v_control_type <> 'id' THEN
 END IF;
 
 SELECT current_setting('search_path') INTO v_old_search_path;
+IF length(v_old_search_path) > 0 THEN
+   v_new_search_path := '@extschema@,pg_temp,'||v_old_search_path;
+ELSE
+    v_new_search_path := '@extschema@,pg_temp';
+END IF;
 IF v_jobmon THEN
     SELECT nspname INTO v_jobmon_schema FROM pg_catalog.pg_namespace n, pg_catalog.pg_extension e WHERE e.extname = 'pg_jobmon'::name AND e.extnamespace = n.oid;
     IF v_jobmon_schema IS NOT NULL THEN
-        v_new_search_path := '@extschema@,'||v_jobmon_schema||',pg_temp';
+        v_new_search_path := format('%s,%s',v_jobmon_schema, v_new_search_path);
     END IF;
 END IF;
 EXECUTE format('SELECT set_config(%L, %L, %L)', 'search_path', v_new_search_path, 'false');
@@ -177,11 +182,12 @@ LOOP
             -- No need to detach partition before dropping since it's going away anyway
             -- Avoids issue of FKs not allowing detachment (Github Issue #294).
             IF v_partition_type = 'native' THEN
-                EXECUTE format('ALTER TABLE %I.%I DETACH PARTITION %I.%I'
+                v_sql := format('ALTER TABLE %I.%I DETACH PARTITION %I.%I'
                     , v_parent_schema
                     , v_parent_tablename
                     , v_row.partition_schemaname
                     , v_row.partition_tablename);
+                EXECUTE v_sql;
             ELSE
                 EXECUTE format('ALTER TABLE %I.%I NO INHERIT %I.%I'
                     , v_row.partition_schemaname
