@@ -19,7 +19,7 @@ v_index                     record;
 v_job_id                    bigint;
 v_jobmon                    boolean;
 v_jobmon_schema             text;
-v_new_search_path           text := '@extschema@,pg_temp';
+v_new_search_path           text;
 v_old_search_path           text;
 v_parent_schema             text;
 v_parent_tablename          text;
@@ -57,6 +57,7 @@ IF p_retention IS NULL THEN
         , retention::interval
         , retention_keep_table
         , retention_keep_index
+        , drop_cascade_fk
         , datetime_string
         , retention_schema
         , jobmon
@@ -68,6 +69,7 @@ IF p_retention IS NULL THEN
         , v_retention
         , v_retention_keep_table
         , v_retention_keep_index
+        , v_drop_cascade_fk
         , v_datetime_string
         , v_retention_schema
         , v_jobmon
@@ -85,6 +87,7 @@ ELSE
         , epoch
         , retention_keep_table
         , retention_keep_index
+        , drop_cascade_fk
         , datetime_string
         , retention_schema
         , jobmon
@@ -94,6 +97,7 @@ ELSE
         , v_epoch
         , v_retention_keep_table
         , v_retention_keep_index
+        , v_drop_cascade_fk
         , v_datetime_string
         , v_retention_schema
         , v_jobmon
@@ -114,10 +118,15 @@ IF v_control_type <> 'time' THEN
 END IF;
 
 SELECT current_setting('search_path') INTO v_old_search_path;
+IF length(v_old_search_path) > 0 THEN
+   v_new_search_path := '@extschema@,pg_temp,'||v_old_search_path;
+ELSE
+    v_new_search_path := '@extschema@,pg_temp';
+END IF;
 IF v_jobmon THEN
     SELECT nspname INTO v_jobmon_schema FROM pg_catalog.pg_namespace n, pg_catalog.pg_extension e WHERE e.extname = 'pg_jobmon'::name AND e.extnamespace = n.oid;
     IF v_jobmon_schema IS NOT NULL THEN
-        v_new_search_path := '@extschema@,'||v_jobmon_schema||',pg_temp';
+        v_new_search_path := format('%s,%s',v_jobmon_schema, v_new_search_path);
     END IF;
 END IF;
 EXECUTE format('SELECT set_config(%L, %L, %L)', 'search_path', v_new_search_path, 'false');
@@ -149,7 +158,7 @@ LOOP
         , v_partition_interval::text
         , p_parent_table);
     -- Add one interval since partition names contain the start of the constraint period
-    IF v_retention < (p_reference_timestamp - (v_partition_timestamp + v_partition_interval)) THEN
+    IF (v_partition_timestamp + v_partition_interval) < (p_reference_timestamp - v_retention) THEN
 
         -- Do not allow final partition to be dropped if it is not a sub-partition parent
         SELECT count(*) INTO v_count FROM @extschema@.show_partitions(p_parent_table);
@@ -173,11 +182,12 @@ LOOP
             -- No need to detach partition before dropping since it's going away anyway
             -- Avoids issue of FKs not allowing detachment (Github Issue #294).
             IF v_partition_type = 'native' THEN
-                EXECUTE format('ALTER TABLE %I.%I DETACH PARTITION %I.%I'
+                v_sql := format('ALTER TABLE %I.%I DETACH PARTITION %I.%I'
                     , v_parent_schema
                     , v_parent_tablename
                     , v_row.partition_schemaname
                     , v_row.partition_tablename);
+                EXECUTE v_sql;
             ELSE
                 EXECUTE format('ALTER TABLE %I.%I NO INHERIT %I.%I'
                         , v_row.partition_schemaname
@@ -303,3 +313,4 @@ DETAIL: %
 HINT: %', ex_message, ex_context, ex_detail, ex_hint;
 END
 $$;
+
